#
# spec file for package gns3
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if %{undefined suse_version}

# get python versions
%global py3_ver %(if [ -f "%{__python3}" ]; then %{__python3} -c "import sys; sys.stdout.write(sys.version[:3])"; else echo 0; fi;)

%endif

Name:           gns3
Summary:        A graphical network simulator
License:        GPL-3.0+
Group:          Productivity/Networking/Other
Version:        1.3.1
Release:        5.2
Url:            http://www.gns3.net/
Source0:        %{name}-gui-%{version}.tar.gz
Source1:        %{name}.png
Source2:        %{name}.xml
Source3:        %{name}.desktop
Source4:        application-x-%{name}.png
Patch0:         %{name}-1.3.0-requires.patch
BuildArch:      noarch
BuildRequires:  desktop-file-utils
BuildRequires:  python3-devel >= 3.3
BuildRequires:  python3-pip
BuildRequires:  python3-qt4-devel
BuildRequires:  python3-setuptools
%if %{defined suse_version}
BuildRequires:  update-desktop-files
%endif
Requires:       gns3-converter
Requires:       gns3-server
Requires:       gns3-server = %{version}
Requires:       python3-apache-libcloud >= 0.14.1
Requires:       python3-configobj
Requires:       python3-paramiko
Requires:       python3-qt4
Requires:       python3-raven
Requires:       python3-requests
Requires:       python3-sip
Provides:       gns3-gui > %{version}
Obsoletes:      gns3-gui <= %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GNS3 is a excellent complementary tool to real labs for administrators
of Cisco networks or people wanting to pass their CCNA,
CCNP, CCIP or CCIE certifications.

It can also be used to experiment features of Cisco IOS or to check configurations
that need to be deployed later on real routers.

Important notice: users must provide their own Cisco IOS to use GNS3.

%prep
%setup -q -n %{name}-gui-%{version}
%patch0 -p1

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}
chmod +x %{buildroot}/%{python3_sitelib}/%{name}/main.py
find %{buildroot}/%{python3_sitelib}/%{name} -name "*.ui" -exec chmod -x {} \;

mkdir -p %buildroot/%{_datadir}/pixmaps
mkdir -p %buildroot/%{_datadir}/mime/packages
mkdir -p %buildroot/%{_datadir}/applications
mkdir -p %buildroot/%{_datadir}/icons/hicolor/48x48/mimetypes
%__cp %SOURCE1 %buildroot/%{_datadir}/pixmaps
%__cp %SOURCE2 %buildroot/%{_datadir}/mime/packages/
%__cp %SOURCE3 %buildroot/%{_datadir}/applications/
%__cp %SOURCE4 %buildroot/%{_datadir}/icons/hicolor/48x48/mimetypes/
rm -rf %{buildroot}/%{python3_sitelib}/tests

%post
/usr/bin/update-mime-database %{_datadir}/mime > /dev/null 2>&1 || :
/usr/bin/update-desktop-database

%postun
/usr/bin/update-mime-database %{_datadir}/mime > /dev/null 2>&1 || :
/usr/bin/update-desktop-database

%files
%defattr(-, root, root, 0755)
%doc AUTHORS LICENSE README.rst
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/48x48
%dir %{_datadir}/icons/hicolor/48x48/mimetypes
%{_datadir}/icons/hicolor/48x48/mimetypes/application-x-%{name}.png
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/pixmaps/%{name}.png
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}_gui-%{version}-py%{py3_ver}.egg-info

%changelog
* Sun Apr 12 2015 andrea@opensuse.org
- New upstream version 1.3.1
  * Fix crash when save as can't create a directory
  * Initial config file content can be empty (fix export issues)
  * Return more informations about bad requests for crash reports
  * Allow less strict dependencies for easier install
  * * Some spring cleaning
  * Fix missing IOU documentation
  * Add missing project name in curl documentation
  * Look in old IOU images location in order to smooth transition
  * Send HTTP errors 400 to the crash report system
  * Fix race condition during old project import
  * Do not overwrite initial-config IOU if client send an empty
  * Fix documentation about /ports/udp
  * Fix rare occasion when user manage to put text in port field
  * Fix a crash when exporting vpcs startup script
  * Fix an issue with sending iourc when a topologies is reloaded
  * Solve issue when iourc contains non ascii characters
  * Handle corrupted zip file with IOS image
  * Don't crash if we try to contact a non GNS3 remote server returning JSON
  * Skip tests in package
  * Check port range
  * Add a warning about too much ram for IOS
  * Fix crash if project is already closed
  * Check if wait for connection thread still running before emitting a signal.
  * Check if process files thread still running before emitting a signal.
  * Raven is an optional dependencies for Debian
  * Fix crash if a dumped topology as no node during save as
  * Fix: remove old ID references for ATM and Frame-Relay switches
* Wed Apr  1 2015 andrea@opensuse.org
- New upstream version 1.3.0
  * Fix etherswitch router
  * Fix issues with progress dialog
  * Fix save as
  * Fix crash when in same occasion the project name is missing
  * Update sentry key
  * Display adapters in the tooltips in the correct order.
  * Open consoles in alphanumerical order.
  * Auto idle-PC improvements.
  * Adds project id when requesting UDP port.
  * Fixes Thread problem. Fixes #229.
  * Cancel network requests if the progress dialog itself is canceled.
    Avoid closing the preferences dialog or any configuration dialog if there is a pending request. Fixes #227.
  * Fixes #228 (no alternative interface has been chosen).
  * Catch OSError when reading or writing the local server config file.
  * Fixes GUI that could not be closed when using an already running local server.
  * Save configs when project is committed.
  * Del key deletes selected link
  * Fix crash is no remote servers is available
  * For more detailed changelog, check https://github.com/GNS3/gns3-gui/releases
- added gns3-1.3.0-requires.patch
* Sat Jan 17 2015 andrea@opensuse.org
- New upstream version 1.2.3
  * Fixed temporary files path setting in general preferences which was not used.
  * Fixed missing devices from the node view when they use a remote server.
  * Fixed broken ASA kernel/initrd file browsers.
  * Fixed bug with WICs interfaces no showing up in the port list.
  * Fixed broken -netdev + legacy virtio in Qemu support.
- New upstream version 1.2.2
  - Small improvements / new features
  * Auxiliary console support for IOS routers.
  * Suspend / resume support for Qemu.
  * Dynamically configure network connections of running Qemu VMs (only with recent Qemu versions).
  * VPCS multi-host support (useful for old .net labs).
  * EtherSwitch routers can be added and configured like other IOS routers.
  * Change hostname option in the contextual device menu.
  * Import & export config options in contextual device menu.
  * Auto screenshot when saving a project.
  * Auto start project support (you have to manually edit your .gns3 project file).
  * Possibility to run VirtualBox as another user (Linux/OSX only).
  * Changes to the IOU L2 initial-config (16 Ethernet interfaces, no shutdown by default and 0 serial interfaces).
  * Upgraded SuperPutty to version 1.4.0.5 in the all-in-one installer.
  * Support for IOURC file on the server side.
  * Bumped the maximum network adapters to 32 for Qemu (depending on Qemu version you cannot go above 8 or
    even 28, Qemu will just not start).
  * Possibility to apply or not the same text to all selected items when editing notes.
  * Added snapshot named 'reset' to linked cloned VirtualBox VMs.
  * Base configs are now stored in the GNS3 config directory.
  * Short port names in the topology summary.
  * Added the VirtualBox VM name in VirtualBox device tooltips.
  * More network interface options to the Qemu VM configuration interface as well as descriptions for all NICs.
  * Set 5 seconds timeout for local server connections.
  * Check if any device runs and warn the user before closing a project.
  * Restore the debug level status when starting.
  * Automatically select the symbol and category corresponding the edited item in the symbol selection dialog.
  * Scale SVG images to icon sizes.
  * Console switching from local/remote to remote/local while a VirtualBox VM is running.
  * More checks on minimum RAM for IOS routers and updates default values to match the latest IOS image requirements.
  * Default Jungle dock location is now bottom right corner.
  - Bug fixes
  * Fixed the default jungle news loading on Windows.
  * Fixed SuperPutty integration (not the default, still have to select it in the preferences).
  * Avoid uninitialized nodes to be saved in the project file.
  * Fixed bug when importing Host node with UDP NIOs.
  * Prevent GNS3 to crash on Windows when importing GNS3 config file.
  * Fixed resource access on Mac OS X.
  * Fixed transparency or border style restoration for ellipses and rectangles.
  * Support spaces in the controller name of VirtualBox clones.
  * Ignore Unicode errors when executing vboxmanage.
  * Get Windows interface list from the registry if the COM service fails.
- removed gns3-1.2.1-fix_transparency.patch now upstream
* Fri Jan  9 2015 andrea@opensuse.org
- make a better use of distro specific macros
* Wed Dec 10 2014 andrea@opensuse.org
- added gns3-1.2.1-fix_transparency.patch to fix a transparency issue with shapes
* Fri Dec  5 2014 andrea@opensuse.org
- New upstream version 1.2.1
  * Early support for IOSv and IOSv-L2 (with Qemu for now, which is slow on Windows/Mac OS X).
  * Support for CPU throttling and process priority for Qemu.
  * Support for full screen mode (View -> Fullscreen).
  * Bundled Qemu 0.13.0 in the Windows all-in-one. Default for all local Qemu VMs.
  * Bundled Qemu 0.14.1 in the Mac OS X App. Default for all local Qemu VMs.
  * Changed ASA defaults to use Qemu 0.13.0 (on Windows), have 4 interfaces and CPU throttling to 65%%.
  * Fixed SecureCRT command line when space in the device name.
  * Fixed C7200 IO cards insert/remove issues and makes C7200-IO-FE the default.
  * Fixed port sorting issues.
  * Added default path for VBoxManage on Mac OS X
  * Upgraded gns3-converter to version 1.1.1 for Windows all-in-one and Mac OS X DMG.
  * New idle-PC field validation.
  * Possibility to load the project from command line (or double-click on a project on Windows).
  * Fixed Unicode error when using VirtualBox VM with a name containing non-english characters.
  * Updated the IOU VM with iouyap version 0.95 (packet capture).
* Tue Nov 25 2014 andrea@opensuse.org
- Fixed license tag
* Thu Nov 20 2014 andrea@opensuse.org
- new upstream version 1.2
  * New VirtualBox support.
  * New GUI styles: charcoal (default) & classic. Changing GUI Preferences
  * Integration of GNS3 converter (allows old .net topologies to be opened).
  * VirtualBox linked clones support (experimental, still some problems with temporary projects).
  * Allow Qemu VM to have no interface.
  * Option to allow console connections to any local IP address when using the local server.
  * Automatically extract IOS configs when a project is closed.
  * Fix "new project" bug when using the GNS3 IOU VM.
  * qemu-system-i386 is the new default on 32-bit platforms.
  * Option to deactivate the new project dialog at startup.
  * Add "open a project" and "recent projects" buttons to the new project dialog.
  * New host node (cloud with all available Ethernet & TAP interfaces added).
  * Fix platform detection issue with some Cisco IOS image file name.
  * Add delay (default 500 ms) when Console to all nodes.
  * Check for duplicate node names in Preferences.
  * Fix bug when editing a Qemu VM configured to run on a remote server.
  * News dock widget is smaller.
  * Add detection of qemu and qemu.exe binaries.
  * New Telnet server for VirtualBox.
- added gns3-converter and python3-configobj as runtime dependencies
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Thu Oct 23 2014 andrea@opensuse.org
- new upstream version 1.1
- bug fixes
  * Warning message when using a remote server with IOU
  * Serial console for VirtualBox
  * Fixes EtherSwitch router
  * New Idle-PC dialog
  * Fixes #123 (Qemu binaries list not showing up)
  * Fixes #119
  * Fixes #126 (broken remote server feature)
  * Fixes #120 (broken cloud)
- removed broken_cloud.patch and broken_server.patch now upstream
* Wed Oct 22 2014 andrea@opensuse.org
- added broken_cloud.patch and broken_server.patch from upstream
  gitcode to fix issue 120 and 121
* Tue Oct 21 2014 andrea@opensuse.org
- New upstream version 1.0
- New features
  * Snapshots support (currently only for local projects).
  * Possibility to configure a category for nodes (routers,
    switches, end devices or security devices).
  * Added support for xfce4-terminal, for Xubuntu.
  * Remote servers and load-balancing (some bugs, still
    things to improve).
  * Check for update feature.
  * GNS3 Jungle dock widget.
  * Getting started dialog.
  * Added path lookup directory for Qemu on OSX.
  * Bug fix when loading a project containing a remote server.
- Know issues and notes
  * VirtualBox support doesn’t work on Mac OS X.
  * VirtualBox support on other platforms hasn’t been fully tested
    and bugs may still be present.
  * Again, regarding VirtualBox integration, we have plans to rewrite
    the back-end to add more features and remove the dependency
    on vboxwrapper.
* Mon Oct 20 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 4
- New features:
  * Preferences has been completely re-vamped for the
    various emulators: Dynamips, IOU, VirtualBox and Qemu.
-Know issues and notes
  * VirtualBox/QEMU on Mac OS X hasn’t been tested at all.
  * VirtualBox support on other platforms hasn’t been fully tested
  and bugs may still be present.
  * Regarding VirtualBox integration, we have plans to rewrite the
  back-end to add more features and remove the dependency on vboxwrapper.
* Thu Sep 25 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 3
- New features
  * QEMU integration with ASA and IDS pre-configuration options.
  * Solarwinds Response Time Viewer integration (Windows 64-bit only).
- know issues and notes
  * VirtualBox support on other platforms hasn’t been fully tested and
    bugs may still be present.
  * Regarding VirtualBox integration, we have plans to rewrite the
    back-end to add more features and remove the dependency on vboxwrapper.
  * We still have a couple of beta releases planned before
    our first release candidate.
* Wed Sep  3 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 2
  * Improved VirtualBox support on Windows and Linux.
  * VirtualBox support on Linux/OSX requires VirtualBox wrapper version >= 9.1
  * New “enable console” option for VirtualBox VMs.
  * New “start at” option for VirtualBox VMs (adapter start index, 0 by default).
  * EtherSwitch support (based on a c3745 image).
  * Multi-drop feature (use SHIFT key while dropping a new node on the drawing area).
  * Default font and color for labels.
  * Support for rectangle and ellipse color transparency.
  * New topology summary options: filter devices with capture(s) and stop all captures.
  * Commands for the GNS3 console (version, start, stop, suspend, reload, show device, show run, help and debug).
  * Layers implementation (anything below layer 0 will be locked to the drawing area).
  * Numeric sorting for Ethernet/hub ports.
  * Restore default buttons for general, packet capture and GNS3 server preferences.
  * Changed the default port ranges.
  * Normalized capture file names.
  * More checks on device names, especially for IOS and IOU which forbid some characters.
  * Handles zoom in or out using the mouse wheel + CTRL. Resets the zoom using CTRL+0.
  * Prevent node labels to be deleted.
  * The sparse memory feature is off by default for c1700 and c2600 platforms (to prevent a bug on reboot).
* Thu Jul 24 2014 andrea@opensuse.org
- New upstream version 1.0 Beta 1
  * Base VirtualBox support (still some issues, most of them on Linux and Mac OS X).
  * Prevent users to set the port and VLAN settings to 0 on Ethernet swithes.
  * Fixed issue when spaces are in capture file paths.
  * Fixed bug with live capture on Windows.
  * Work around for the c7200 reload bug in Dynamips <= 0.2.13.
  * Fixed some inconsistencies when exporting configs.
  * The early release dialog is gone!
* Thu Jul 10 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 8
  * New feature: insert an image on the view.
  * New feature: change node symbols.
  * Default port configuration for Ethernet switch and hub devices.
  * New feature: import/export device configs.
  * Fixed issue when deleting note items that had parent items.
  * Check the minimum required amount of RAM when adding IOS images.
  * Start a packet capture from the device contextual menu.
  * Improvements on the topology summary and link highlighting.
  * Find an alternative IOS or IOU image if one cannot be found when importing a topology.
  * Find an alternative Ethernet interface if one cannot be found when importing a topology.
  * Use Windows interface names instead of their GUID (more user friendly).
  * Fixed IOU and VPCS renaming issues.
  * Fixed size restoration issues for rectangles and ellipses when loading a project.
  * Check for VPCS version >= 0.5b1
  * Fixed errors when connecting an IOU device to a cloud.
  * Packet capture for IOU works with the latest iouyap version (0.95) available here.
* Tue Jul  1 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 7
  * Packet capture for IOS routers.
  * Packet capture for the Ethernet hub and Ethernet,
    ATM and Frame relay switches.
  * Packet capture for IOU (not working, issue with iouyap).
  * Add notes, rectangles & ellipses to topologies.
  * Show/hide interface labels.
  * Contextual device menu.
  * Recent file menu.
  * Lab instructions support (automatically open any file named
    instructions.* in the project directory or from the Help menu)
  * Load a project by dropping the project file on the view.
  * Duplicate option for notes, rectangles and ellipses.
  * Style settings for note, rectangle and ellipse items. Possibility
    to edit interface and node labels.
  * Fix: use Dynamips, IOU and VPCS identifiers to correctly
    load topologies.
  * IOU: rename startup-config to initial-config (makes more
    sense for IOU).
  * Option to uncompress IOS images.
  * Check for sticky bit when checking for executable access.
  * Fix: IOS image relative path problems.
  * Lots of small bug fixes.
* Sat May 31 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 6
  * New host names management.
  * New project dialog (in preparation for cloud support).
  * Logs saved to files (GNS3_client.log and GNS3_server.log).
  * Relative paths support for IOS/IOU images in project files.
  * Fixed decoding errors when reading device configs.
  * Fixed privileged access checks for IOU.
  * Fixed validation issue with c2600 XM chassis.
  * Fixed VPCS start on Linux/UNIX.
  * Fixed Ethernet hub when loading a project.
* Tue May 27 2014 andrea@opensuse.org
- added new dependency python3-requests
* Thu May 22 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 5
  * VPCS support (only version >= 0.5b1
  * Fixed console port errors when loading a project.
  * Fixed startup-config errors when loading a project.
  * Fixed minor issues on Mac OS X (DMG file coming soon).
  * IOU default startup-configs for layer 2 and layer 3 images.
    Allowing for faster loading times too.
  * Option to prevent starting the local server when openning the GUI.
  * Prevent devices to be started, stopped or suspended if their status is not right
  * More checks for cloud connections.
  * Show item coordinates in the status bar.
  * Amend device configs (hostname) when renaming.
  * UDP connection checks.
* Thu May 15 2014 andrea@opensuse.org
- New upstream version 1.0 alpha 4
  * Show Windows interface names in cloud tooltips.
  * Disconnect the server if the version differs from the GUI version.
  * Move cloud code to a builtin module and support for clouds on remote servers.
  * Options to use the default IOU RAM & NVRAM values.
  * Changed the name of default base startup and private configs.
  * Added “All files” filter when looking for an IOU or IOS image in the file broswer.
  * Graceful server shutdown on Windows.
  * Error message that JIT sharing is only supported in Dynamips unstable.
  * New UDP and console port allocation system for IOU. Fixes duplicated port issues.
  * Delete some Dynamips files that are useless to save in projects.
  * Fix: the path to GNS3 server was not saved.
  * Fix: RAM and NVRAM IOU image settings not propagated when creating an IOU device.
  * Fix: bug where IOS nvram/disk files were not kept after closing a topology.
  * Fix: bug that prevented changing any IOU device setting when connected to another node.
  * Fix: duplicated node id issue.
  * Fix: major bug with ghost instance overwriting any second router files (R2).
  * Fix: error when ldd cannot be found.
  * Fix: issues with local base configs for IOS.
* Thu May  8 2014 andrea@opensuse.org
- Improved spec file, added fdupes and made rpmlint happy
* Wed May  7 2014 andrea@opensuse.org
- Spec file clean up
* Fri Apr 25 2014 andrea@opensuse.org
- new upstream version 0.8.7
  * no changelog provided
  * no URL exist for the tarball, taken from GIT-HUB
* Sat Nov 16 2013 badshah400@gmail.com
- Minor spec file cleanups:
  + Remove package name from summary tag in spec file
  + Use full URL for source tarball.
* Sat Nov  9 2013 andrea@opensuse.org
- new upstream version 0.8.6
  * Fixed the broken snapshot feature.
  * Host devices don’t automatically add tap interfaces in the
    generic Ethernet NIO list anymore.
  * Auto open for instructions files when opening the topology via
    the command line, a file explorer or a drag & drop on the workspace.
  * Modified the default Etherswitch configuration (renamed some macros
    + added vtp file nvram:vlan.dat)
  * Fixed small bugs with “idlepc get” command and Ethernet
    switch auto port allocation.
  * New Dutch translation & Italian translation updated.
* Sun Sep 15 2013 andrea@opensuse.org
- new upstream version 0.8.5
  * New symbols for ASA, Qemu guest and Vbox guest.
  * Fixed a major issue that prevented to use the auto
    idle-pc calculation feature.
  * Implemented the Restore snapshot feature following
    Rednectar’s suggestions (http://forum.gns3.net/post20664.html#p20664)
  * Snapshots are now stored in a separate directory inside project directory.
  * Increased lowest and max zoom values.
  * Updated Italian translation.
  * Added Xshell 4 command lines in terminal settings.
  * Fixed issue with the contextual device menu.
  * Fixed bug when launching VPCS and there was a space in the project path.
  * Option ‘Use hypervisor manager’ changed to ‘Bind to external
    hypervisor(s)’ (logic is inverted) in IOS images and hypervisors dialog.
  * Checks: if VPCS is installed and if Dynamips is marked as executable.
  * Added instructions entry to Help menu.
  * Automatic opening of instructions file when loading a project.
  * Fixed Teraterm, SecureCRT and Konsole terminal command lines.
  * Added “-vga none” option to ASA Pre-configuration.
  * Updated the SecureCRT script to automatically reconnect if disconnected.
  * Fixed a bug with load-balancing on multiple external hypervisors.
  * Fixed issue when binding Qemuwrapper to a PC’s real IP address.
  * Various other small bug fixes.
* Sun Jul  7 2013 andrea@opensuse.org
- new upstream version 0.8.4
  * Lots of GUI improvements.
  * New hub device.
  * New Idlemax and Idlesleep settings (advanced manipulation of IDLE PC).
  * IOS image and settings test button.
  * New Tool menu to start external scripts/tools.
  * Drag & drop of multiple devices when pressing SHIFT.
  * Temporary projects are created by default.
  * VirtualBox interface numbering starts at 0 (e.g. e0 = VirtualBox
    interface 1 = eth0 on Linux).
  * Support for 36 network cards in VirtualBox (using ICH9 chipset)
  * New option to save traffic captures in project directories.
  * Experimental auto IDLE PC calculation feature.
  * Added entries to have Dynamips/Qemu/VirtualBox hypervisors bind/listen to
    all available IP/host addresses (optional).
  * AW+ router support by Allied Telesis from New Zealand (educational version of
    their OS to be released).
  * Removed the “Save IOS configs option” in project settings. IOS configs are
    always saved.
  * Qemu FLASH files are automatically saved in a directory named
    ‘qemu-flash-drives’ (in the project directory).
* Mon Jan  7 2013 andrea@opensuse.org
- new upstream version 0.8.3.1
  * minor fixes and support for access to GNS3 VirtualBox VM hostnames
    from inside VMs (e.g. VBoxControl guestproperty get NameInGNS3)
  * includes updated vboxwrapper that work with the new VirtualBox 4.2
- removed gns3-0.8.3-defaults.diff now in upstream code
* Sun Aug  5 2012 andrea@opensuse.org
- added gns3-0.8.3-defaults.diff to fix wrong default VBOX paths
* Sun Aug  5 2012 andrea@opensuse.org
- New upstream version 0.8.3
  * New base configuration (startup-config) for devices with
    NM-16ESW (named baseconfig_sw.txt). =
  * Support for drag & drop of topology files inside GNS3.
  * Global TCP port tracker to allocate ports and avoid conflicts
    (console + AUX ports for IOS routers and console ports for
    Qemu-like/VirtualBox devices are tracked).
  * Option to freely use the first VBox interface inside VMs
    (i.e. eth0 on Linux).
  * Backup nvram export when Dynamips has crashed.
  * Complete IPv6 support (with correct functions).
  * Support for binding on specific addresses when loading a topology.
  * Option to track opened node consoles in order to close them when the
    node gets deleted.
* Wed Apr 18 2012 lars@linux-schulserver.de
- fix license to be in spdx format
* Sun Apr 15 2012 andrea@opensuse.org
- New upstream version 0.8.2 (Virtual box support)
* Tue May 31 2011 coolo@novell.com
- brequire update-desktop-file
* Mon May  9 2011 andrea@opensuse.org
- Added vde2 as recommended app
* Sun May  8 2011 andrea@opensuse.org
- Removed from spec files instructions for unsupported suse version
- Moved qemu and wireshark to Recommends and not Requires
* Mon Apr 18 2011 andrea@opensuse.org
- added man page
* Tue Apr 12 2011 andrea@opensuse.org
- new upstream version 0.7.4
  * Greek translation
  * Hypervisor allocation per IOS type
  * Improvements on Ethernet Switch (dynamic remapping of VLAN or type)
  * Adaptations to support Dynamips 0.2.8 RC3 community
  * Integration of a loopback manager for Windows
* Sun Apr 10 2011 andrea@opensuse.org
- added mime type for .net topology files
* Mon Feb  7 2011 andrea@opensuse.org
- New upstream version 0.7.3
  * Only the necessary files (nvram, flash, disks etc.) are copied
  or kept when creating projects and snapshots.
  * Preventing unsaved interface labels to show up after loading a
  topology. This can be reset using the
  "show interface labels" button.
  * Improvements for ATM and Frame Relay switches: proper naming,
  dynamic mapping support and it is not needed to remove a link to
  change its DLCI/VC mapping.
  * PCAP capture support for Qemu based devices
  (Qemu host, JunOS ASA, PIX, IDS). This option cannot be used after
  the selected device is started.
  * Fixed many issues with the snapshot feature.
  Now it should work as expected.
  * New node type: EtherSwitch router. This is a c3700 router
  with a Etherswitch NM-16ESW loaded.
  * Better consistency between buttons and menus. Many items have
  been renamed, toolbar buttons accessible from the menu etc.
  * Possibility to configure the AUX port. Only works for c7200 routers
  (Preferences -> Dynamips -> Base AUX port).
  * Changed standard naming convention for project and snapshots.
  Topology file is named topology.net, working directory: working and
  configurations directory: configs.
  * Double click on a running node opens a console.
  * Reload all devices option.
  * Translation updates.
  * Many more
* Mon Oct 25 2010 andrea@opensuse.org
- New upstream version 0.7.2
- Installed qemuwrapper utils
- added qemu as dependency
* Fri Jun  4 2010 andrea@opensuse.org
- New upstream version 0.7.1
* Tue Dec  1 2009 andrea@opensuse.org
- fixed 11.2 building (as noarch)
* Sun Jun  7 2009 Andrea Florio <andrea@opensuse.org> 0.6.1
- new upstream version 0.6.1
* Fri Dec 19 2008 Andrea Florio <andrea@opensuse.org> 0.6
- new upstream version 0.6
* Wed Nov  5 2008 Andrea Florio <andrea@opensuse.org>
- no longer a no arch. py_sitedit is /usr/lib/ecc or /usr/lib64/ecc
* Mon Aug  4 2008 Andrea Florio <andrea@opensuse.org>
- new package
- added menu icon
